# Anomalies
Implement the anomaly free solution or  arXiv:1905.13729

## Install
```bash
$ pip install anomalies
```
## USAGE
```python
>>> from anomalies import anomaly
>>> anomaly.free([-1,1],[4,-2])
```
